@@ -1,10 +1,7 @@
-from jinja2 import Template
-
-from moto.ec2.models import ec2_backend
-from moto.ec2.utils import resource_ids_from_querystring
+from moto.core.responses import BaseResponse
 
 
-class Monitoring(object):
+class Monitoring(BaseResponse):
     def monitor_instances(self):
         raise NotImplementedError('Monitoring.monitor_instances is not yet implemented')
 
