@@ -28,12 +28,12 @@ class DomainDispatcherApplication(object):
 
     def get_backend_for_host(self, host):
         if self.service:
-            return BACKENDS[self.service]
+            return self.service
 
-        for backend in BACKENDS.itervalues():
+        for backend_name, backend in BACKENDS.iteritems():
             for url_base in backend.url_bases:
                 if re.match(url_base, 'http://%s' % host):
-                    return backend
+                    return backend_name
 
         raise RuntimeError('Invalid host: "%s"' % host)
 
@@ -82,7 +82,11 @@ def main(argv=sys.argv[1:]):
     parser = argparse.ArgumentParser()
 
     # Keep this for backwards compat
-    parser.add_argument("service", type=str)
+    parser.add_argument(
+        "service",
+        type=str,
+        nargs='?',  # http://stackoverflow.com/a/4480202/731592
+        default=None)
     parser.add_argument(
         '-H', '--host', type=str,
         help='Which host to bind',
